@@ -60,13 +60,15 @@ class Monitor:
         t1.start()
         t2.start()
 
-    @staticmethod
-    def api_run(host, port):
+
+    def api_run(self, host, port):
         app = Flask(__name__)
 
         @app.route('/api/ai/service_monitor', methods=['GET'])
         def get_service_health():
-            record_path_list = eval(record_paths)
+            record_path_list = []
+            for service in self.service_list:
+                record_path_list.append(service.name)
             path_fix = '/var/log/event/control_log/'
             error_time_list = []
             for _ in record_path_list:
@@ -126,10 +128,6 @@ class Monitor:
 
         if log_check != 0:
             log.info(f"{self.time}T{hour_str} 无法在日志文件中查询到，请及时查看处理")
-            self.send_alarm2developer(f"{self.time}T{hour_str} 无法在日志文件中查询到，请及时查看处理", service.dingtalk_function)
-            service_name = service.name if not service.restart_name else service.restart_name
-            self.restart_service(service_name, service.dingtalk_function, service.restart_flag)
-            check_times = 0
 
         ws['A1'].value = new_data_bytes
         ws['B1'].value = check_times
@@ -215,8 +213,8 @@ class ServiceHealthApi(MethodView):
         for _ in record_path_list:
             record_path = path_fix + _ + '_monitor.xlsx'
             wb = openpyxl.load_workbook(record_path)
-            ws = wb.actice
-            error_times = ws['C1']
+            ws = wb.active
+            error_times = ws['C1'].value
             error_time_list.append(error_times)
             wb.close()
 
@@ -247,30 +245,30 @@ class Service:
 
 
 if __name__ == '__main__':
-    app = Flask(__name__)
-
-    @app.route('/api/ai/service_monitor', methods=['GET'])
-    def get_service_health():
+    # app = Flask(__name__)
+    #
+    # @app.route('/api/ai/service_monitor', methods=['GET'])
+    # def get_service_health():
         # record_path = request.args.get('record_path')
         # wb = openpyxl.load_workbook(record_path)
         # ws = wb.active
         # error_times = ws['A1'].value
         # wb.close()
 
-        error_times = 1
-
-        if error_times < 3:
-            response = {'msg': '服务正常', 'code': 200,
-                        'data': error_times}
-            return jsonify(response)
-        else:
-            msg = {'msg': '服务异常'}
-            # 构建一个response
-            response = make_response(json.dumps(msg), 400)
-            return response
-
-    app.config['env'] = 'development'
-    app.run(host='0.0.0.0', port=5001)
+    #     error_times = 1
+    #
+    #     if error_times < 3:
+    #         response = {'msg': '服务正常', 'code': 200,
+    #                     'data': error_times}
+    #         return jsonify(response)
+    #     else:
+    #         msg = {'msg': '服务异常'}
+    #         # 构建一个response
+    #         response = make_response(json.dumps(msg), 400)
+    #         return response
+    #
+    # app.config['env'] = 'development'
+    # app.run(host='0.0.0.0', port=5001)
 
     # wb = openpyxl.Workbook()
     # ws = wb.active
@@ -301,3 +299,31 @@ if __name__ == '__main__':
     # s = a.name if not a.restart_name else a.restart_name
     # print(s)
 
+    app = Flask(__name__)
+
+
+    @app.route('/api/ai/service_monitor', methods=['GET'])
+    def get_service_health(record_paths):
+        record_path_list = eval(record_paths)
+        path_fix = '/Users/ouyangyi/ilabservice/'
+        error_time_list = []
+        for _ in record_path_list:
+            record_path = path_fix + _ + '_monitor.xlsx'
+            wb = openpyxl.load_workbook(record_path)
+            ws = wb.actice
+            error_times = ws['C1']
+            error_time_list.append(error_times)
+            wb.close()
+
+        if max(error_time_list) < 3:
+            response = {'msg': '服务正常', 'code': 200,
+                        'data': error_time_list}
+            return jsonify(response)
+        else:
+            msg = {'msg': '服务异常'}
+            response = make_response(json.dumps(msg), 400)
+            return response
+
+    app.config['env'] = 'development'
+    app.run(host='0.0.0.0', port=5001)
+
